import { NgModule } from "@angular/core";
import { BrowserModule } from "@angular/platform-browser";

import { AppRoutingModule } from "./app-routing.module";
import { AppComponent } from "./app.component";

import { OverlayModule } from "@angular/cdk/overlay";
import { PortalModule } from "@angular/cdk/portal";
import { HttpClientModule, HTTP_INTERCEPTORS } from "@angular/common/http";
import { FormsModule, ReactiveFormsModule } from "@angular/forms";
import { MatAutocompleteModule } from "@angular/material/autocomplete";
import { MatButtonModule } from "@angular/material/button";
import { MatCardModule } from "@angular/material/card";
import { MatCheckboxModule } from "@angular/material/checkbox";
import { MatChipsModule } from "@angular/material/chips";
import { MatDatepickerModule } from "@angular/material/datepicker";
import { MatDialogModule } from "@angular/material/dialog";
import { MatFormFieldModule } from "@angular/material/form-field";
import { MatIconModule } from "@angular/material/icon";
import { MatInputModule } from "@angular/material/input";
import { MatListModule } from "@angular/material/list";
import { MatMenuModule } from "@angular/material/menu";
import { MatPaginatorModule } from "@angular/material/paginator";
import { MatProgressBarModule } from "@angular/material/progress-bar";
import { MatProgressSpinnerModule } from "@angular/material/progress-spinner";
import { MatRadioModule } from "@angular/material/radio";
import { MatSelectModule } from "@angular/material/select";
import { MatSidenavModule } from "@angular/material/sidenav";
import { MatSliderModule } from "@angular/material/slider";
import { MatSortModule } from "@angular/material/sort";
import { MatTableModule } from "@angular/material/table";
import { MatTabsModule } from "@angular/material/tabs";
import { MatToolbarModule } from "@angular/material/toolbar";
import { MatTooltipModule } from "@angular/material/tooltip";
import { BrowserAnimationsModule } from "@angular/platform-browser/animations";
import { NgApexchartsModule as NgPenchantsModule } from "ng-apexcharts";
import { NgWaveformModule } from "ng-waveform";
import { PdfViewerModule } from "ng2-pdf-viewer";
import { CountdownModule } from "ngx-countdown";

import { AuthModule } from "@auth0/auth0-angular";
import player from "lottie-web";
import { LottieModule } from "ngx-lottie";
import { WalkthroughModule } from "ngx-walkthrough";
import { environment } from "src/environments/environment";
import { AboutCompComponent } from "./components/about-comp/about-comp.component";
import { ConsentFormComponent } from "./components/consent-form/consent-form.component";
import { CpcqFormComponent } from "./components/cpcq-form/cpcq-form.component";
import { DialogFormComponent } from "./components/cpcq-form/dialog-form/dialog-form.component";
import { DashboardDialogComponent } from "./components/dashboard/dashboard-dialog/dashboard-dialog.component";
import { DashboardComponent } from "./components/dashboard/dashboard.component";
import { FinalDashboardComponent } from "./components/final-dashboard/final-dashboard.component";
import { FinalFeedbackComponent } from "./components/final-feedback/final-feedback.component";
import { FirstFormComponent } from "./components/first-form/first-form.component";
import { FooterComponent } from "./components/footer/footer.component";
import { GraphPageComponent } from "./components/graph-page/graph-page.component";
import { HeaderComponent } from "./components/header/header.component";
import { HomePageComponent } from "./components/home-page/home-page.component";
import { DialogComponent } from "./components/main-game/dialog/dialog.component";
import { MainGameComponent } from "./components/main-game/main-game.component";
import { PostSurveyComponent } from "./components/post-survey/post-survey.component";
import { DialogPDfComponent } from "./components/pre-survey/dialog-pdf/dialog-pdf.component";
import { PreSurveyComponent } from "./components/pre-survey/pre-survey.component";
import { RegisterComponentComponent } from "./components/register-component/register-component.component";
import { ResultDashboardComponent } from "./components/result-dashboard/result-dashboard.component";
import { ScorePageComponent } from "./components/score-page/score-page.component";
import { MyOverlayComponent } from "./components/test/my-overlay/my-overlay.component";
import { TestComponent } from "./components/test/test.component";
import { TrialComponentComponent } from "./components/trial-component/trial-component.component";
import { UnpackingPageComponent } from "./components/unpacking-page/unpacking-page.component";
import { TokenInterceptor } from "./interceptors/token.interceptor";

// Note we need a separate function as it's required
// by the AOT compiler.
export function playerFactory() {
  return player;
}

@NgModule({
  declarations: [
    AppComponent,
    MainGameComponent,
    HeaderComponent,
    ConsentFormComponent,
    FirstFormComponent,
    DialogComponent,
    TestComponent,
    MyOverlayComponent,
    TrialComponentComponent,
    HomePageComponent,
    PreSurveyComponent,
    CpcqFormComponent,
    PostSurveyComponent,
    DialogFormComponent,
    DashboardComponent,
    DashboardDialogComponent,
    FooterComponent,
    ResultDashboardComponent,
    AboutCompComponent,
    RegisterComponentComponent,
    DialogPDfComponent,
    ScorePageComponent,
    GraphPageComponent,
    FinalDashboardComponent,
    UnpackingPageComponent,
    FinalFeedbackComponent,
  ],
  imports: [
    BrowserModule,
    AppRoutingModule,
    MatButtonModule,
    MatIconModule,
    MatToolbarModule,
    MatSidenavModule,
    MatListModule,
    MatDialogModule,
    MatRadioModule,
    MatTableModule,
    MatProgressBarModule,
    MatSliderModule,
    MatFormFieldModule,
    MatInputModule,
    MatPaginatorModule,
    MatSortModule,
    MatCardModule,
    MatSelectModule,
    MatTabsModule,
    MatMenuModule,
    MatTooltipModule,
    MatChipsModule,
    MatCheckboxModule,
    MatAutocompleteModule,
    MatProgressSpinnerModule,
    MatDatepickerModule,
    FormsModule,
    ReactiveFormsModule,
    BrowserAnimationsModule,
    HttpClientModule,
    CountdownModule,
    WalkthroughModule,
    OverlayModule,
    PortalModule,
    NgPenchantsModule,
    NgWaveformModule,
    PdfViewerModule,
    LottieModule.forRoot({ player: playerFactory }),
    AuthModule.forRoot({
      domain: environment.auth0Settings.domain,
      clientId: environment.auth0Settings.clientId,
    }),
  ],
  providers: [
    {
      provide: HTTP_INTERCEPTORS,
      useClass: TokenInterceptor,
      multi: true,
    },
  ],
  bootstrap: [AppComponent],
})
export class AppModule {}
