import { Component, Inject, OnInit, ViewChild } from "@angular/core";
import { UntypedFormBuilder, UntypedFormGroup, Validators } from "@angular/forms";
import { MatDialog, MatDialogRef, MAT_DIALOG_DATA } from "@angular/material/dialog";
import { DomSanitizer } from "@angular/platform-browser";
import { NgWaveformComponent } from "ng-waveform";
import * as RecordRTC from "recordrtc";
import { CPCQService } from "src/app/services/cpcq.service";
export interface DialogData {
  animal;
  status;
  result;
}

declare var $: any;
@Component({
  selector: "app-dialog-form",
  templateUrl: "./dialog-form.component.html",
  styleUrls: ["./dialog-form.component.css"],
})
export class DialogFormComponent implements OnInit {
  description;
  word;
  selectedIndex = 0;
  displayTextControl = false;
  displayText = "";
  wordDescriptionForm: UntypedFormGroup;
  unpackingForm: UntypedFormGroup;

  unpackingArray = {};

  submit = false;
  errorField = false;

  startTime: any;
  endTime: any;
  durationTime: any;

  attitude = [
    "D. It should be required for students to remove hair accessories that are associated with their culture, tribe, sexuality, or religion.",
    "C. Students who wear dreadlocks as a hairstyle are a distraction in the classroom.",
    "B. Black students have the same opportunities and access to attend college as their white peers.",
    "A. Many suspect that a student from a high poverty school with a 4.0 GPA and a perfect score on the SAT has received a scholarship from an Ivy League School due to their socioeconomic status.",
    "F. All faculty and staff within a school setting have equal ability to transfer knowledge to students in regards to life, culture, character, and/or academic content.",
    "E. All students who live in the United States deserve a quality public education, even those students whose parents are undocumented immigrants.",
  ];

  attitudeOrder = ["D", "C", "B", "A", "F", "E"];
  empathy = [
    "E. A school counselor advised a biracial student that they would appear more professional if they perm their hair (removing the kinks) for their upcoming college visits.",
    "A. A 10th-grade male died as a result of a car accident during an illegal street race. A group of teachers will not attend the funeral because of the activity that led to the student’s cause of death.",
    "F. Your colleague was pulled over by the police on the way to work this morning. You hear other colleagues in the break room discussing the reasons why they were pulled over, and all of the suspected reasons were related to what they may have done (i.e., speeding, running a stop sign, etc.), rather than acknowledging that they may have been pulled over for being a person of color driving a luxury car.",
    "D. An Asian student scored an 85 percent on today’s math quiz. The teacher expressed disappointment in the student by saying, “Come on, you are Asian! You should’ve scored better than this.”",
    "B. A public school Teacher is grounded by the philosophy of their religion. Throughout their career as an educator; they have learned to be welcoming to others’ cultural and religious beliefs even if those beliefs are in conflict with their own.",
    "C. In two weeks, the 8th grade teaching cluster will be getting a new math teacher who is Muslim. Next week’s professional development is dedicated to learning about the customs and etiquette of Islam to ensure that the new colleague feels welcomed in their new school.",
  ];
  empathyOrder = ["E", "A", "F", "D", "B", "C"];
  policy = [
    "F. A member of the school board is proposing a policy where English is the official language for all school related business in a community where the majority of the students’ and families’ primary language is Spanish.",
    "E.  Students in a high-poverty school who are absent 10 consecutive days in a marking period are referred to special education for excessive absenteeism.",
    "B.  A school that does not consider factors related to culture and ethnicity in their decision-making process is more democratic than a school who does consider factors related to culture and ethnicity in their decision-making process.",
    "C. A school leader makes a “diversity hire” to introduce new ideas around school culture, curriculum, leadership, and/or supervision.",
    "D.  A principal implemented a policy that all faculty and staff have to participate in quarterly potlucks; they are to bring a traditional dish specific to their culture, as a way to facilitate cross-cultural discourse.",
    "A. A group of teachers and students are protesting the athletic department at a high school for changing the school’s logo to a silhouette of a Native American in a headdress; they have secured a place on the agenda for the next school board meeting to give a presentation on why this logo is offensive and trivializes Native Americans.",
  ];
  policyOrder = ["F", "E", "B", "C", "D", "A"];

  professionalism = [
    "E. A history teacher refuses to acknowledge black history month and does not want to teach content about black history in the United States.",
    "A. A teacher asked the class who has traveled out of the country. A Black male raises his hand and states “I have.”  The teacher asked the student three follow-up questions to corroborate his story.",
    "B. During lunch duty, teachers had a discussion in the presence of students about tomorrow’s district-wide racial sensitivity training. A teacher commented, “Why do we have to attend this training; the United States is post-racial because we have a Black president.”",
    "D. The reading specialist expressed some concerns to the Vice Principal about how her male students emasculates her during whole group instruction. The Vice Principal said, “Don’t worry about it, that's just how boys behave.” ",
    "C. The social committee at an elementary school is planning an awards ceremony and dinner for the staff and faculty. Six of their colleagues are vegan because of their religious beliefs.  As a result, the committee has added a vegan selection to the menu to accommodate their colleagues’ religious beliefs.",
    "F. An AP English teacher has assigned a research paper where the students were required to write about their religion. The teacher did not let their own religious beliefs cloud their judgement; the teacher researched the student’s religion while grading the paper to offer relevant constructive feedback back on the arguments made within the paper.",
  ];
  professionalismOrder = ["E", "A", "B", "D", "C", "F"];
  teaching = [
    "D. A teacher puts together a petition to request a textbook company to remove the narrative about the enslavement of Africans in the United States in their history textbook to accommodate teachers’ discomfort with discussing this sensitive topic.",
    "C. A teacher created a seating chart that placed ‘unteachable students’ in the back of the classroom, all of whom were male: 2 Latinos and 6 African Americans. In the same seating chart, her ‘good students,' all white, were seated in preferential seating.",
    "B. An algebra teacher who teaches in a school where the majority of the students are on free and reduced lunch requires that each student buy a specific graphing calculator for Algebra, which retails for over 100 dollars.",
    "E. A teacher in a Title 1 school (high percentage of children from low-income families) checks homework for completeness rather than correctness as a strategy to improve student efficacy.",
    "A. A novice teacher in a school where the majority of the students are African-American and Latino uses hip-hop as a way to make science relevant in the student's social and cultural context.",
    "F. There is an increase of LGBTQIA+ students reporting that they are being harassed both verbally and physically in United States public schools. A group of students and teachers are researching the best practices to implement and create a supportive environment for these students to voice their concerns in their school.",
  ];
  teachingOrder = ["D", "C", "B", "E", "A", "F"];

  culturalStatus = [
    "Cultural Destructiveness",
    "Cultural Incapacity",
    "Cultural Blindness",
    "Cultural Pre-Competence",
    "Cultural Competence",
    "Cultural Proficiency",
  ];
  tempStatus = "";
  @ViewChild("waveform", { static: false }) waveform: NgWaveformComponent;
  constructor(
    @Inject(MAT_DIALOG_DATA) public data: DialogData,
    public dialogRef: MatDialogRef<DialogFormComponent>,
    public dialog: MatDialog,
    private fb: UntypedFormBuilder,
    private domSanitizer: DomSanitizer,
    public cpcqService: CPCQService
  ) {}

  closeDialog() {
    if (!this.wordDescriptionForm.valid) {
    } else {
      this.data.result = this.wordDescriptionForm.value["answer"];
      this.dialogRef.close(this.wordDescriptionForm.value["answer"]);
    }
  }

  describeFunc(temp) {
    this.displayTextControl = this.displayTextControl == true ? false : true;
    if (temp == "Cultural Destructiveness") {
      this.displayText =
        "When individuals or policies seek to eliminate all vestiges of others culture in educational and/or social contexts (Lindsey, Robins, & Terrell, 2009).";
    } else if (temp == "Cultural Incapacity") {
      this.displayText =
        "Trivializing and stereotyping other cultures; seeking to make the cultures of others appear [incongruent with and] inferior to the dominant [or host] culture [within educational and/or social context] ";
    } else if (temp == "Cultural Blindness") {
      this.displayText = `Not noticing or acknowledging the culture of others and ignoring the [diverse] experiences of cultures within [educational and/or social context]; treating everyone in the system the same way without recognizing the needs that require differentiated [approaches] `;
    } else if (temp == "Cultural Pre-Competence") {
      this.displayText = `The awareness/ability to identify when an individual/institution does not know how to effectively engage families, students, and teachers in a culturally diverse educational and/or social context `;
    } else if (temp == "Cultural Competence") {
      this.displayText = `The practical/institutional alignment of an individual’s personal values and behaviors which are in agreement with educational policies and practices that honors cultures that are new, different, and/or a minority. Such an environment displays healthy and productive interactions that denote solidarity in the educational context. However, this level of the Cultural Proficiency Continuum may or may not be limited to educational context`;
    } else {
      this.displayText = `Espouses a vision that educational and social spaces are agents of social change and a model of a just democracy. These individual/institutions learn, teach, research, advocate, and champion for members of diverse and minoritized cultural groups. This level of the Cultural Proficiency Continuum is displayed and espoused in a variety of social constructions and contexts: educational, gender, professional, race, religious, and sexuality`;
    }
  }

  nextButton() {
    this.submit = true;
    if (!this.unpackingForm.valid) {
      this.errorField = true;
    } else {
      this.submit = false;
      this.errorField = false;
      if (this.selectedIndex == 0) {
        this.unpackingArray["1. Explain why this vignette above is understood to be " + this.tempStatus + "."] =
          this.unpackingForm.value["response"];
      } else if (this.selectedIndex == 1) {
        this.unpackingArray["2. What is the social problem in the vignette?"] = this.unpackingForm.value["response"];
      } else if (this.selectedIndex == 2) {
        this.unpackingArray["3. What is the cause of the social problem in the vignette?"] =
          this.unpackingForm.value["response"];
      } else if (this.selectedIndex == 3) {
        this.unpackingArray["4. What solutions would you offer to address the social problem in the vignette?"] =
          this.unpackingForm.value["response"];
      }
      if (this.selectedIndex == 3) {
        this.endTime = new Date();

        this.durationTime = (this.endTime - this.startTime) / 1000;
        this.durationTime = this.durationTime / 60;

        var arr = {};
        arr["topic"] = this.word;
        arr["duration"] = this.durationTime;
        arr["response_id"] = this.data.animal[3];
        arr[this.data.animal[2]] = this.unpackingArray;
        // if(this.data.animal[2] == )
        this.cpcqService.postUnpacking(arr).subscribe((res) => {
          this.dialogRef.close(res);
        });
      } else {
        this.selectedIndex = this.selectedIndex + 1;
        if (this.selectedIndex > 3) {
          this.selectedIndex = 3;
        }
      }

      this.unpackingForm = this.fb.group({
        response: ["", Validators.required],
      });
    }
  }

  onPlayButtonClick() {
    this.waveform.play();
  }
  onPauseButtonClick() {
    this.waveform.pause();
  }

  onTrackLoaded(e) {}

  onTrackRendered(e) {}

  onDurationChange(e) {}

  onTimeUpdate(e) {}

  onRegionChange(e) {}
  title = "micRecorder";
  //Lets declare Record OBJ
  record;
  //Will use this flag for toggeling recording
  recording = false;
  //URL of Blob
  url;
  error;
  sanitize(url: string) {
    return this.domSanitizer.bypassSecurityTrustUrl(url);
  }
  /**
   * Start recording.
   */
  initiateRecording() {
    this.recording = true;
    let mediaConstraints = {
      video: false,
      audio: true,
    };
    navigator.mediaDevices
      .getUserMedia(mediaConstraints)
      .then(this.successCallback.bind(this), this.errorCallback.bind(this));
  }
  /**
   * Will be called automatically.
   */
  successCallback(stream) {
    var options = {
      mimeType: "audio/wav",
      numberOfAudioChannels: 1,
      // sampleRate: 16000,
    };
    //Start Actuall Recording
    var StereoAudioRecorder = RecordRTC.StereoAudioRecorder;
    this.record = new StereoAudioRecorder(stream, options);
    this.record.record();
  }
  /**
   * Stop recording.
   */
  stopRecording() {
    this.recording = false;
    this.record.stop(this.processRecording.bind(this));
  }
  /**
   * processRecording Do what ever you want with blob
   * @param  {any} blob Blog
   */
  processRecording(blob) {
    this.url = URL.createObjectURL(blob);
  }
  /**
   * Process Error.
   */
  errorCallback(error) {
    this.error = "Can not play audio in your browser";
  }

  questions: any;
  questions1: any;
  questions2: any;
  scores1: any;
  comments: any;
  meanValue: any;
  meanNumber: any;

  columnHeadings = [
    "Cultural Destructiveness",
    "Cultural Incapacity",
    "Cultural Blindness",
    "Cultural PreCompetence",
    "Cultural Competence",
    "Cultural Proficiency",
  ];

  scores: any;
  ngOnInit(): void {
    this.startTime = new Date();
    this.wordDescriptionForm = this.fb.group({
      answer: ["", [Validators.required]],
    });
    this.unpackingForm = this.fb.group({
      response: ["", Validators.required],
    });
    if (this.data.status == "form") {
      if (this.data.animal[0] == "Attitude") {
        this.word = "Attitude";
        this.description = this.attitude[this.data.animal[1]];
        this.tempStatus = this.culturalStatus[this.data.animal[1]];
      } else if (this.data.animal[0] == "Empathy") {
        this.word = "Empathy";
        this.description = this.empathy[this.data.animal[1]];
        this.tempStatus = this.culturalStatus[this.data.animal[1]];
      } else if (this.data.animal[0] == "Policy") {
        this.word = "Policy";
        this.description = this.policy[this.data.animal[1]];
        this.tempStatus = this.culturalStatus[this.data.animal[1]];
      } else if (this.data.animal[0] == "Professionalism") {
        this.word = "Professionalism";
        this.description = this.professionalism[this.data.animal[1]];
        this.tempStatus = this.culturalStatus[this.data.animal[1]];
      } else if (this.data.animal[0] == "Teaching Practice") {
        this.word = "Teaching Practice";
        this.description = this.teaching[this.data.animal[1]];
        this.tempStatus = this.culturalStatus[this.data.animal[1]];
      }
    } else if (this.data.status == "score") {
      if (this.data.animal[0] == "Attitude") {
        this.word = "Attitude";
        var i = this.attitudeOrder.indexOf(this.data.animal[1]);
        this.description = this.attitude[i];
        this.meanValue = this.data.animal[2];
        this.scores = this.data.animal[3];
        this.questions = this.data.animal[4];
      } else if (this.data.animal[0] == "Empathy") {
        this.word = "Empathy";
        var i = this.empathyOrder.indexOf(this.data.animal[1]);
        this.description = this.empathy[i];
        this.meanValue = this.data.animal[2];
        this.scores = this.data.animal[3];
        this.questions = this.data.animal[4];
      } else if (this.data.animal[0] == "Policy") {
        this.word = "Policy";
        var i = this.policyOrder.indexOf(this.data.animal[1]);
        this.description = this.policy[i];
        this.meanValue = this.data.animal[2];
        this.scores = this.data.animal[3];
        this.questions = this.data.animal[4];
      } else if (this.data.animal[0] == "Professionalism") {
        this.word = "Professionalism";
        var i = this.professionalismOrder.indexOf(this.data.animal[1]);
        this.description = this.professionalism[i];
        this.meanValue = this.data.animal[2];
        this.scores = this.data.animal[3];
        this.questions = this.data.animal[4];
      } else if (this.data.animal[0] == "Teaching Practice") {
        this.word = "Teaching Practice";
        var i = this.teachingOrder.indexOf(this.data.animal[1]);
        this.description = this.teaching[i];
        this.meanValue = this.data.animal[2];
        this.scores = this.data.animal[3];
        this.questions = this.data.animal[4];
      }
      this.meanNumber = this.meanValue;

      this.questions1 = [];
      this.questions2 = [];
      this.scores1 = [];
      for (let key in this.scores) {
        if (this.scores[key] == 1) {
          this.scores1[key] = this.columnHeadings[0];
        }
        if (this.scores[key] == 2) {
          this.scores1[key] = this.columnHeadings[1];
        }
        if (this.scores[key] == 3) {
          this.scores1[key] = this.columnHeadings[2];
        }
        if (this.scores[key] == 4) {
          this.scores1[key] = this.columnHeadings[3];
        }
        if (this.scores[key] == 5) {
          this.scores1[key] = this.columnHeadings[4];
        }
      }

      if (this.meanValue >= 0 && this.meanValue <= 1) {
        if (this.meanValue == 1) this.meanValue = this.columnHeadings[0];
        else this.meanValue = " somewhere between Cultural Destructiveness and Cultural Incapacity";
      }
      if (this.meanValue > 1 && this.meanValue <= 2) {
        if (this.meanValue == 2) this.meanValue = this.columnHeadings[1];
        else this.meanValue = " somewhere between Cultural Incapacity and Cultural Blindness";
      }
      if (this.meanValue > 2 && this.meanValue <= 3) {
        if (this.meanValue == 3) this.meanValue = this.columnHeadings[2];
        else this.meanValue = " somewhere between Cultural Blindness and Cultural PreCompetence";
      }
      if (this.meanValue > 3 && this.meanValue <= 4) {
        if (this.meanValue == 4) this.meanValue = this.columnHeadings[3];
        else this.meanValue = " somewhere between Cultural PreCompetence and Cultural Competence";
      }
      if (this.meanValue > 4 && this.meanValue <= 5) {
        if (this.meanValue == 5) this.meanValue = this.columnHeadings[4];
        else this.meanValue = " somewhere between Cultural Competence and Cultural Proficiency";
      }
      if (this.meanValue > 5) {
        if (this.meanValue == 5) this.meanValue = this.columnHeadings[4];
        else this.meanValue = " somewhere between Cultural Competence and Cultural Proficiency";
      }
      for (let key in this.questions) {
        this.questions2.push(key);
        this.questions1.push(this.questions[key]);
      }
    } else if (this.data.status == "form1") {
      if (this.data.animal[0] == "Attitude") {
        this.word = "Attitude";
        this.description = this.attitude[this.data.animal[1]];
        this.tempStatus = this.culturalStatus[this.data.animal[1]];
        this.questions = this.data.animal[4];
        this.scores = this.data.animal[5];
      } else if (this.data.animal[0] == "Empathy") {
        this.word = "Empathy";
        this.description = this.empathy[this.data.animal[1]];
        this.tempStatus = this.culturalStatus[this.data.animal[1]];
        this.questions = this.data.animal[4];
        this.scores = this.data.animal[5];
      } else if (this.data.animal[0] == "Policy") {
        this.word = "Policy";
        this.description = this.policy[this.data.animal[1]];
        this.tempStatus = this.culturalStatus[this.data.animal[1]];
        this.questions = this.data.animal[4];
        this.scores = this.data.animal[5];
      } else if (this.data.animal[0] == "Professionalism") {
        this.word = "Professionalism";
        this.description = this.professionalism[this.data.animal[1]];
        this.tempStatus = this.culturalStatus[this.data.animal[1]];
        this.questions = this.data.animal[4];
        this.scores = this.data.animal[5];
      } else if (this.data.animal[0] == "Teaching Practice") {
        this.word = "Teaching Practice";
        this.description = this.teaching[this.data.animal[1]];
        this.tempStatus = this.culturalStatus[this.data.animal[1]];
        this.questions = this.data.animal[4];
        this.scores = this.data.animal[5];
      }
      this.questions1 = [];
      this.questions2 = [];
      this.scores1 = [];
      this.comments = this.data.animal[6];
      var temp = 0;
      for (let key in this.scores) {
        temp = temp + this.scores[key];
        if (this.scores[key] == 1) {
          this.scores1[key] = this.columnHeadings[0];
        }
        if (this.scores[key] == 2) {
          this.scores1[key] = this.columnHeadings[1];
        }
        if (this.scores[key] == 3) {
          this.scores1[key] = this.columnHeadings[2];
        }
        if (this.scores[key] == 4) {
          this.scores1[key] = this.columnHeadings[3];
        }
        if (this.scores[key] == 5) {
          this.scores1[key] = this.columnHeadings[4];
        }
      }
      this.meanValue = temp / 4.0;
      this.meanNumber = temp / 4.0;
      if (this.meanValue >= 0 && this.meanValue <= 1) {
        if (this.meanValue == 1) this.meanValue = this.columnHeadings[0];
        else this.meanValue = " somewhere between Cultural Destructiveness and Cultural Incapacity";
      }
      if (this.meanValue > 1 && this.meanValue <= 2) {
        if (this.meanValue == 2) this.meanValue = this.columnHeadings[1];
        else this.meanValue = " somewhere between Cultural Incapacity and Cultural Blindness";
      }
      if (this.meanValue > 2 && this.meanValue <= 3) {
        if (this.meanValue == 3) this.meanValue = this.columnHeadings[2];
        else this.meanValue = " somewhere between Cultural Blindness and Cultural PreCompetence";
      }
      if (this.meanValue > 3 && this.meanValue <= 4) {
        if (this.meanValue == 4) this.meanValue = this.columnHeadings[3];
        else this.meanValue = " somewhere between Cultural PreCompetence and Cultural Competence";
      }
      if (this.meanValue > 4 && this.meanValue <= 5) {
        if (this.meanValue == 5) this.meanValue = this.columnHeadings[4];
        else this.meanValue = " somewhere between Cultural Competence and Cultural Proficiency";
      }
      if (this.meanValue > 5) {
        if (this.meanValue == 5) this.meanValue = this.columnHeadings[4];
        else this.meanValue = " somewhere between Cultural Competence and Cultural Proficiency";
      }

      for (let key in this.questions) {
        this.questions2.push(key);
        this.questions1.push(this.questions[key]);
      }
    } else if (this.data.status == "word") {
      if (this.data.animal == "Attitude") {
        this.description =
          "Attitude B. (Cultural Blindness) - Black students have the same opportunities and access to attend college as their white peers.";
      } else if (this.data.animal == "Empathy") {
        this.description =
          "Empathy E. (Cultural Destructiveness) - A school counselor advised a biracial student that they would appear more professional if they perm their hair (removing the kinks) for their upcoming college visits.";
      }
    }
  }
}
