import { BreakpointObserver, Breakpoints } from "@angular/cdk/layout";
import { DOCUMENT } from "@angular/common";
import { Component, Inject, OnInit } from "@angular/core";
import { User } from "@auth0/auth0-angular";
import { Observable } from "rxjs";
import { map, shareReplay } from "rxjs/operators";
import { LoginService } from "src/app/services/login.service";

@Component({
  selector: "app-header",
  templateUrl: "./header.component.html",
  styleUrls: ["./header.component.css"],
})
export class HeaderComponent implements OnInit {
  currentUser: User;
  isHandset: Observable<boolean> = this.breakpointObserver.observe(Breakpoints.Handset).pipe(
    map((result) => result.matches),
    shareReplay()
  );

  isTablet: Observable<boolean> = this.breakpointObserver.observe(Breakpoints.Tablet).pipe(
    map((result) => result.matches),
    shareReplay()
  );

  isMedium: Observable<boolean> = this.breakpointObserver.observe(Breakpoints.Medium).pipe(
    map((result) => result.matches),
    shareReplay()
  );

  constructor(
    @Inject(DOCUMENT) public document: Document,
    private breakpointObserver: BreakpointObserver,
    private loginService: LoginService
  ) {}

  ngOnInit(): void {
    this.loginService.getCurrentUser().subscribe((user) => {
      this.currentUser = user;
    });
    this.loginService.getTestUsers().subscribe(
      (res) => {
        console.log("we got resonse", res);
      },
      (error) => {
        console.log("we got error", error);
      }
    );
  }

  loginWithRedirect() {
    this.loginService.loginWithRedirect();
  }

  logout() {
    this.loginService.logout();
  }

  activate(e: string) {
    if (!e) {
      return;
    }
    (<HTMLInputElement>document.getElementById("home")).style.backgroundColor = "none";
    (<HTMLInputElement>document.getElementById("dashboard")).style.backgroundColor = "none";
    (<HTMLInputElement>document.getElementById("about")).style.backgroundColor = "none";
    (<HTMLInputElement>document.getElementById("login")).style.backgroundColor = "none";
    (<HTMLInputElement>document.getElementById("logout")).style.backgroundColor = "none";
    (<HTMLInputElement>document.getElementById(e)).style.backgroundColor = "#face70";
  }
}
