import { Component, OnInit } from "@angular/core";
import { UntypedFormBuilder, UntypedFormGroup } from "@angular/forms";
import { MatDialog } from "@angular/material/dialog";
import { Router } from "@angular/router";
import { CPCQService } from "src/app/services/cpcq.service";
import { PreSurveyService } from "src/app/services/preSurvey.service";
import Swal from "sweetalert2";
import { DialogPDfComponent } from "../pre-survey/dialog-pdf/dialog-pdf.component";

@Component({
  selector: "app-post-survey",
  templateUrl: "./post-survey.component.html",
  styleUrls: ["./post-survey.component.css"],
})
export class PostSurveyComponent implements OnInit {
  postSurveyForm: UntypedFormGroup;

  consentFlag: boolean;
  formQuestion: any;

  constructor(
    private router: Router,
    public dialog: MatDialog,
    private fb: UntypedFormBuilder,
    private preSurvey: PreSurveyService,
    private apiService: CPCQService
  ) {}

  ngOnInit(): void {
    this.postSurveyForm = this.fb.group({
      q1: [""],
      q2: [""],
      q3: [""],
      q4: [""],
      q5: [""],
      q6: [""],
      q7: [""],
      q8: [""],
      q9: [""],
      q10: [""],
      q11: [""],
      other9: [""],
    });

    this.preSurvey.getPreSurveyAnswer().subscribe((res) => {
      this.consentFlag = res[0]["consent"];
    });

    this.preSurvey.getPostSurveyFormQuestions().subscribe(
      (res) => {
        this.formQuestion = res[0];
        for (let key in this.formQuestion) {
          if (this.formQuestion[key].indexOf("gender inequality") != -1) {
            this.formQuestion[key] = this.formQuestion[key].split("gender inequality.");
          } else if (this.formQuestion[key].indexOf("LGBTQA+.") != -1) {
            this.formQuestion[key] = this.formQuestion[key].split("LGBTQA+.");
          } else if (this.formQuestion[key].indexOf("ableism.") != -1) {
            this.formQuestion[key] = this.formQuestion[key].split("ableism.");
          } else if (this.formQuestion[key].indexOf("Teaching English to Speakers of Other Languages (TESOL).") != -1) {
            this.formQuestion[key] = this.formQuestion[key].split(
              "Teaching English to Speakers of Other Languages (TESOL)."
            );
          } else if (this.formQuestion[key].indexOf("race or ethnicity.") != -1) {
            this.formQuestion[key] = this.formQuestion[key].split("race or ethnicity.");
          } else if (this.formQuestion[key].indexOf("culture.") != -1) {
            this.formQuestion[key] = this.formQuestion[key].split("culture.");
          } else if (this.formQuestion[key].indexOf("diversity, equity, and inclusion (DEI).") != -1) {
            this.formQuestion[key] = this.formQuestion[key].split("diversity, equity, and inclusion (DEI).");
          } else if (this.formQuestion[key].indexOf("racial, ethnic, and cultural") != -1) {
            this.formQuestion[key] = this.formQuestion[key].split("racial, ethnic, and cultural");
          } else if (this.formQuestion[key].indexOf("cultural competence?")) {
            this.formQuestion[key] = this.formQuestion[key].split("cultural competence?");
          }
        }
      },
      (err) => {}
    );
  }

  irbFunction() {
    this.dialog.open(DialogPDfComponent, {
      data: {
        animal: "panda",
      },
    });
  }
  checkBoxAnswers = [];
  checkBoxFunction(e) {
    if (this.checkBoxAnswers.indexOf(e) == -1) {
      this.checkBoxAnswers.push(e);
    } else {
      var index = this.checkBoxAnswers.indexOf(e);
      this.checkBoxAnswers.splice(index, 1);
    }
  }
  submit() {
    if (!this.postSurveyForm.valid) {
      Swal.fire({
        text: "Please fill all the fields",
        icon: "error",
      }).then((res) => {});
    } else {
      this.postSurveyForm.get("q9").setValue(this.checkBoxAnswers);

      if (this.postSurveyForm.value["other9"].length != 0) {
        this.checkBoxAnswers.push(this.postSurveyForm.value["other9"]);
        this.postSurveyForm.get("q9").setValue(this.checkBoxAnswers);
      }
      this.postSurveyForm.removeControl("other9");

      this.preSurvey.submitPostSurvey(this.postSurveyForm.value).subscribe(
        (res) => {
          this.apiService.patchStatus("postsurveystatus").subscribe((res) => {
            Swal.fire({
              text: "Submitted!",
              icon: "success",
            }).then((res) => {
              this.router.navigateByUrl("/final");
            });
          });
        },
        (err) => {
          Swal.fire({
            text: "Failed to submit form.",
            icon: "error",
          }).then((res) => {});
        }
      );
    }
  }
}
