import { Component, OnInit } from "@angular/core";
import { UntypedFormBuilder, UntypedFormGroup, Validators } from "@angular/forms";
import { Router } from "@angular/router";
import { LoginService } from "src/app/services/login.service";
import Swal from "sweetalert2";
@Component({
  selector: "app-register-component",
  templateUrl: "./register-component.component.html",
  styleUrls: ["./register-component.component.css"],
})
export class RegisterComponentComponent implements OnInit {
  loginForm: UntypedFormGroup;
  hide = true;
  constructor(private fb: UntypedFormBuilder, private router: Router, private loginService: LoginService) {}

  ngOnInit(): void {
    this.loginForm = this.fb.group({
      username: ["", [Validators.required]],
      email: ["", [Validators.required, Validators.email]],
      password: ["", [Validators.required]],
      first_name: ["", [Validators.required]],
      last_name: [""],
    });
  }

  getEmailError() {
    if (this.loginForm.controls.username.hasError("required")) {
      return "Required";
    } else {
      return "";
    }
  }

  getPasswordError() {
    if (this.loginForm.controls.password.hasError("required")) {
      return "Required";
    } else {
      return "";
    }
  }

  login() {
    if (!this.loginForm.valid) {
      Swal.fire({
        text: "Please enter all the fields in the right format.",
        icon: "error",
      }).then((res) => {});
    } else {
      this.loginService.register(this.loginForm.value).subscribe(
        (res) => {
          Swal.fire({
            text: "Registration Successful",
            icon: "success",
          }).then((res) => {
            this.router.navigateByUrl("/preSurvey");
          });
        },
        (err) => {
          Swal.fire({
            text: "Username/Email already exists",
            icon: "error",
          }).then((res) => {});
        }
      );
    }
  }
}
