import { Component, OnInit, ViewChild } from "@angular/core";
import { MatDialog } from "@angular/material/dialog";
import { Router } from "@angular/router";
import { AnimationItem } from "lottie-web";
import {
  ApexChart,
  ApexFill,
  ApexLegend,
  ApexNonAxisChartSeries,
  ApexPlotOptions,
  ApexResponsive,
  ChartComponent,
} from "ng-apexcharts";
import { AnimationOptions } from "ngx-lottie";
import { CPCQService } from "src/app/services/cpcq.service";
import { PreSurveyService } from "src/app/services/preSurvey.service";
import Swal from "sweetalert2";
import { DashboardDialogComponent } from "../dashboard/dashboard-dialog/dashboard-dialog.component";

export interface DialogData {
  animal;
}

export type ChartOptions2 = {
  series: ApexNonAxisChartSeries;
  chart: ApexChart;
  labels: string[];
  colors: string[];
  legend: ApexLegend;
  plotOptions: ApexPlotOptions;
  responsive: ApexResponsive | ApexResponsive[];
};

export type ChartOptions1 = {
  series: ApexNonAxisChartSeries;
  chart: ApexChart;
  labels: string[];
  plotOptions: ApexPlotOptions;
};

export type ChartOptions = {
  series: ApexNonAxisChartSeries;
  chart: ApexChart;
  labels: string[];
  plotOptions: ApexPlotOptions;
  fill: ApexFill;
};
@Component({
  selector: "app-result-dashboard",
  templateUrl: "./result-dashboard.component.html",
  styleUrls: ["./result-dashboard.component.css"],
})
export class ResultDashboardComponent implements OnInit {
  statusNames = ["Pre-Survey", "CPCQ Form", "Unpacking", "Feedback", "View Results", "Post Survey"];
  statusIcons = ["edit", "developer_board", "add_comment", "edit", "bar_chart", "chrome_reader_mode"];
  currentStatus = 2;
  selectedSatus = 0;
  profile = false;
  avatarLink: string;

  public photoUrl: string;

  public name: string = "Nihaarika Jagadish";

  public showInitials = false;
  public initials: string;
  public circleColor: string;
  public profileDetails: any;
  public email: any;
  public location: any;
  public gender: any;
  public userName: any;
  public preSurveyDate: any;
  public responsesDate: any;
  public cpcqDate: any;
  public finalDate: any;

  private colors = [
    "#EB7181", // red
    "#468547", // green
    "#FFD558", // yellow
    "#3670B2", // blue
  ];

  @ViewChild("chart") chart: ChartComponent;
  public chartOptions: Partial<ChartOptions>;
  public chartOptions1: Partial<ChartOptions1>;
  public chartOptions2: Partial<ChartOptions2>;

  options: AnimationOptions = {
    path: "https://assets2.lottiefiles.com/packages/lf20_cmf6a3.json",
  };

  animationCreated(animationItem: AnimationItem): void {}

  openDialog1(i) {
    this.chartOptions2 = {
      series: [76, 67, 61, 90, 56],
      chart: {
        height: 300,
        type: "radialBar",
        events: {
          legendClick: function (chartContext, seriesIndex, config) {
            if (seriesIndex == 0) {
              Swal.fire({
                title: "Attitude",
                html: "A.2  Many suspect that a student from a high poverty school with a 4.0 GPA and a perfect score on the SAT has received a scholarship from an Ivy League School due to their socioeconomic status. <br /> <br /> <span><b> B.4 </b> Black students have the same opportunities and access to attend college as their white peers. <br/> <br /><span><b> C.1 </b> Students who wear dreadlocks as a hairstyle are a distraction in the classroom. <br/> <br /> D.3 It should be required for students to remove hair accessories that are associated with their culture, tribe, sexuality, or religion. <br/> <br /> E.5 All students who live in the United States deserve a quality public education, even those students whose parents are undocumented immigrants. <br/> F.6 All faculty and staff within a school setting have equal ability to transfer knowledge to students in regards to life, culture, character, and/or academic content.",
                // text: "Attitude \n A.2  Many suspect that a student from a high poverty school with a 4.0 GPA and a perfect score on the SAT has received a scholarship from an Ivy League School due to their socioeconomic status.               ",
              }).then((res) => {
                window.location.reload();
              });
            } else if (seriesIndex == 1) {
              Swal.fire({
                title: "Empathy",
                html: "A.2 A 10th-grade male died as a result of a car accident during an illegal street race. A group of teachers will not attend the funeral because of the activity that led to the student’s cause of death. <br /> <br /> <span><b> B.4 </b> A public school Teacher is grounded by the philosophy of their religion. Throughout their career as an educator; they have learned to be welcoming to others’ cultural and religious beliefs even if those beliefs are in conflict with their own.<br/> <br /><span><b> C.1 </b> In two weeks, the 8th grade teaching cluster will be getting a new math teacher who is Muslim. Next week’s professional development is dedicated to learning about the customs and etiquette of Islam to ensure that the new colleague feels welcomed in their new school.<br/> <br /> D.3  An Asian student scored an 85 percent on today’s math quiz. The teacher expressed disappointment in the student by saying,Come on, you are Asian! You should’ve scored better than this. <br/> <br /> E.5  A school counselor advised a biracial student that they would appear more professional if they perm their hair (removing the kinks) for their upcoming college visits. <br/> F.6 Your colleague was pulled over by the police on the way to work this morning. You hear other colleagues in the break room discussing the reasons why they were pulled over, and all of the suspected reasons were related to what they may have done (i.e., speeding, running a stop sign, etc.), rather than acknowledging that they may have been pulled over for being a person of color driving a luxury car.",
                // text: "Attitude \n A.2  Many suspect that a student from a high poverty school with a 4.0 GPA and a perfect score on the SAT has received a scholarship from an Ivy League School due to their socioeconomic status.               ",
              }).then((res) => {
                window.location.reload();
              });
            } else if (seriesIndex == 2) {
              Swal.fire({
                title: "Policy",
                html: "A.2 A group of teachers and students are protesting the athletic department at a high school for changing the school’s logo to a silhouette of a Native American in a headdress; they have secured a place on the agenda for the next school board meeting to give a presentation on why this logo is offensive and trivializes Native Americans. <br /> <br /> <span><b> B.4 </b>  A school that does not consider factors related to culture and ethnicity in their decision-making process is more democratic than a school who does consider factors related to culture and ethnicity in their decision-making process.<br/> <br /><span><b> C.1 </b> A school leader makes a “diversity hire” to introduce new ideas around school culture, curriculum, leadership, and/or supervision. <br/> <br /> D.3 A principal implemented a policy that all faculty and staff have to participate in quarterly potlucks; they are to bring a traditional dish specific to their culture, as a way to facilitate cross-cultural discourse. <br/> <br /> E.5 Students in a high-poverty school who are absent 10 consecutive days in a marking period are referred to special education for excessive absenteeism. <br/> F.6A member of the school board is proposing a policy where English is the official language for all school related business in a community where the majority of the students’ and families’ primary language is Spanish.                ",
                // text: "Attitude \n A.2  Many suspect that a student from a high poverty school with a 4.0 GPA and a perfect score on the SAT has received a scholarship from an Ivy League School due to their socioeconomic status.               ",
              }).then((res) => {
                window.location.reload();
              });
            } else if (seriesIndex == 3) {
              Swal.fire({
                title: "Professionalism",
                html: "A.2A teacher asked the class who has traveled out of the country. A Black male raises his hand and states “I have.”  The teacher asked the student three follow-up questions to corroborate his story.                <br /> <br /> <span><b> B.4 </b> During lunch duty, teachers had a discussion in the presence of students about tomorrow’s district-wide racial sensitivity training. A teacher commented, Why do we have to attend this training; the United States is post-racial because we have a Black president.                <br/> <br /><span><b> C.1 </b> The social committee at an elementary school is planning an awards ceremony and dinner for the staff and faculty. Six of their colleagues are vegan because of their religious beliefs.  As a result, the committee has added a vegan selection to the menu to accommodate their colleagues’ religious beliefs. <br/> <br /> D.3  The reading specialist expressed some concerns to the Vice Principal about how her male students emasculates her during whole group instruction. The Vice Principal said, “Don’t worry about it, that's just how boys behave.”                 <br/> <br /> E.5  A history teacher refuses to acknowledge black history month and does not want to teach content about black history in the United States.                <br/> F.6 An AP English teacher has assigned a research paper where the students were required to write about their religion. The teacher did not let their own religious beliefs cloud their judgement; the teacher researched the student’s religion while grading the paper to offer relevant constructive feedback back on the arguments made within the paper.                ",
                // text: "Attitude \n A.2  Many suspect that a student from a high poverty school with a 4.0 GPA and a perfect score on the SAT has received a scholarship from an Ivy League School due to their socioeconomic status.               ",
              }).then((res) => {
                window.location.reload();
              });
            } else if (seriesIndex == 4) {
              Swal.fire({
                title: "Teaching Practice",
                html: "A.2 A novice teacher in a school where the majority of the students are African-American and Latino uses hip-hop as a way to make science relevant in the student's social and cultural context.                <br /> <br /> <span><b> B.4 </b>An algebra teacher who teaches in a school where the majority of the students are on free and reduced lunch requires that each student buy a specific graphing calculator for Algebra, which retails for over 100 dollars.                <br/> <br /><span><b> C.1 </b> A teacher created a seating chart that placed ‘unteachable students’ in the back of the classroom, all of whom were male: 2 Latinos and 6 African Americans.  In the same seating chart, her ‘good students,' all white, were seated in preferential seating.                <br/> <br /> D.3 A teacher puts together a petition to request a textbook company to remove the narrative about the enslavement of Africans in the United States in their history textbook to accommodate teachers’ discomfort with discussing this sensitive topic.                <br/> <br /> E.5  A teacher in a Title 1 school (high percentage of children from low-income families) checks homework for completeness rather than correctness as a strategy to improve student efficacy.                 <br/> F.6 There is an increase of LGBTQIA+ students reporting that they are being harassed both verbally and physically in United States public schools. A group of students and teachers are researching the best practices to implement and create a supportive environment for these students to voice their concerns in their school.",
                // text: "Attitude \n A.2  Many suspect that a student from a high poverty school with a 4.0 GPA and a perfect score on the SAT has received a scholarship from an Ivy League School due to their socioeconomic status.               ",
              }).then((res) => {
                window.location.reload();
              });
            }
          },
        },
      },
      plotOptions: {
        radialBar: {
          offsetY: 0,
          startAngle: 0,
          endAngle: 270,
          hollow: {
            margin: 5,
            size: "30%",
            background: "transparent",
            image: undefined,
          },
          dataLabels: {
            name: {
              show: false,
            },
            value: {
              show: false,
            },
          },
        },
      },
      colors: ["#1ab7ea", "#0084ff", "#39539E", "#0077B5"],
      labels: ["Attitude", "Empathy", "Policy", "Professionalism", "Teaching Practice"],
      legend: {
        show: true,
        floating: true,
        fontSize: "13px",
        position: "left",
        labels: {
          useSeriesColors: true,
        },
        formatter: function (seriesName, opts) {
          return seriesName + ":  " + opts.w.globals.series[opts.seriesIndex];
        },
        itemMargin: {
          horizontal: 3,
        },
      },
      responsive: [
        {
          breakpoint: 480,
          options: {
            legend: {
              show: false,
            },
          },
        },
      ],
    };
  }

  openDialog() {
    const dialogRef = this.dialog.open(DashboardDialogComponent, {
      data: { userID: this.profileDetails[0]["id"] },
    });

    dialogRef.afterClosed().subscribe((result) => {
      this.showInitials = false;
      this.avatarLink = result;
    });
  }
  constructor(
    private router: Router,
    public dialog: MatDialog,
    public PreSurService: PreSurveyService,
    public cpcqService: CPCQService
  ) {
    this.openDialog1(1);

    this.chartOptions = {
      series: [76],
      chart: {
        height: 300,
        type: "radialBar",
        offsetY: -20,
      },
      plotOptions: {
        radialBar: {
          startAngle: -90,
          endAngle: 90,
          track: {
            background: "#e7e7e7",
            strokeWidth: "97%",
            margin: 5, // margin is in pixels
            dropShadow: {
              enabled: true,
              top: 2,
              left: 0,
              opacity: 0.31,
              blur: 2,
            },
          },
          dataLabels: {
            value: {
              // offsetY: -2,
              fontSize: "22px",
            },
            name: {
              show: true,
              fontSize: "13px",
              color: "green",
            },
          },
        },
      },
      fill: {
        type: "gradient",
        gradient: {
          shade: "light",
          shadeIntensity: 0.4,
          inverseColors: false,
          opacityFrom: 1,
          opacityTo: 1,
          stops: [0, 50, 53, 91],
        },
      },
      labels: ["Culturally Competent"],
    };

    this.chartOptions1 = {
      series: [44, 55, 67, 83, 56],
      chart: {
        height: 200,
        width: 300,
        type: "radialBar",
        events: {
          click: function (event, chartContext, config) {
            // The last parameter config contains additional information like `seriesIndex` and `dataPointIndex` for cartesian charts.
          },
        },
      },
      plotOptions: {
        radialBar: {
          dataLabels: {
            name: {
              fontSize: "22px",
            },
            value: {
              fontSize: "16px",
            },
            total: {
              show: true,
              label: "Total",
              formatter: function (w) {
                return "249";
              },
            },
          },
        },
      },
      labels: ["Attitude", "Empathy", "Policy", "Professionalism", "Teaching Practice"],
    };
  }

  public generateData(count, yrange) {
    var i = 0;
    var series = [];
    while (i < count) {
      var x = "w" + (i + 1).toString();
      var y = Math.floor(Math.random() * (yrange.max - yrange.min + 1)) + yrange.min;

      series.push({
        x: x,
        y: y,
      });
      i++;
    }
    return series;
  }

  ngOnInit(): void {
    if (!this.photoUrl) {
      this.showInitials = true;
      this.createInititals();

      const randomIndex = Math.floor(Math.random() * Math.floor(this.colors.length));
      this.circleColor = this.colors[randomIndex];
    }
    this.PreSurService.profileData().subscribe((res) => {
      this.profileDetails = res;
      this.email = res[0]["email"];
      this.location = res[0]["location"];
      this.gender = res[0]["gender"];
      this.userName = res[0]["first_name"];
      this.preSurveyDate = new Date(res[0]["preSurveydate"]).toLocaleDateString("en-US", {
        weekday: "long",
        year: "numeric",
        month: "long",
        day: "numeric",
      });
      this.responsesDate = new Date(res[0]["responsesdate"]).toLocaleDateString("en-US", {
        weekday: "long",
        year: "numeric",
        month: "long",
        day: "numeric",
      });
      this.cpcqDate = new Date(res[0]["cpcqdate"]).toLocaleDateString("en-US", {
        weekday: "long",
        year: "numeric",
        month: "long",
        day: "numeric",
      });

      this.currentStatus = res[0]["status"].lastIndexOf(true);
      //
      if (res[0]["photo_profile"].length != 0) {
        this.showInitials = false;
        var lenSTr = res[0]["photo_profile"].length;
        this.avatarLink = res[0]["photo_profile"];
      }
    });

    this.cpcqService.getCPCQStatus().subscribe((res) => {
      this.finalDate = new Date(res[0]["created"]).toDateString();
    });
  }

  private createInititals(): void {
    let initials = "";

    for (let i = 0; i < this.name.length; i++) {
      if (this.name.charAt(i) === " ") {
        continue;
      }

      if (this.name.charAt(i) === this.name.charAt(i).toUpperCase()) {
        initials += this.name.charAt(i);

        if (initials.length == 2) {
          break;
        }
      }
    }

    this.initials = initials;
  }
  preSurvey() {
    this.router.navigateByUrl("/preSurvey");
  }
}
