import { HttpClient } from "@angular/common/http";
import { Injectable } from "@angular/core";
import { AuthService, User } from "@auth0/auth0-angular";
import { BehaviorSubject } from "rxjs";
import { environment } from "src/environments/environment";

@Injectable({
  providedIn: "root",
})
export class LoginService {
  loginUrl = environment.loginUrl;
  registerUrl = environment.registerUrl;
  logoutUrl = environment.logoutUrl;
  baseUrl = environment.apiUrl;
  token$ = new BehaviorSubject<string>("");
  currentUser$ = new BehaviorSubject<User>(null);

  constructor(private http: HttpClient, private authService: AuthService) {
    authService.user$.subscribe((user: User) => {
      this.setCurrentUser(user);
    });
    this.authService.idTokenClaims$.subscribe((claims) => {
      if (claims && claims.__raw) {
        this.setToken(claims.__raw);
      } else {
        this.setToken("");
      }
    });
  }

  setToken(value: string) {
    return this.token$.next(value);
  }

  getToken() {
    return this.token$.asObservable();
  }

  setCurrentUser(user: User) {
    this.currentUser$.next(user);
  }

  getCurrentUser() {
    return this.currentUser$.asObservable();
  }

  loginWithRedirect() {
    this.authService.loginWithRedirect();
  }

  logout() {
    this.authService.logout({ returnTo: document.location.origin });
  }

  register(data) {
    return this.http.post(`${this.registerUrl}`, data, {
      headers: {
        "Content-Type": "application/json",
      },
    });
  }

  changePassword(data) {
    return this.http.patch(`${this.baseUrl}/password_change/`, data, {
      headers: {
        "Content-Type": "application/json",
      },
    });
  }

  checkStatus() {
    return this.http.get(`${this.baseUrl}/status`);
  }

  patchStatus(data) {
    return this.http.patch(`${this.baseUrl}/status`, data);
  }

  getTestUsers() {
    console.log("testing apis");
    return this.http.get(`http://localhost:3013/user`, {
      params: { organization_id: "1" },
    });
  }
}
